@@ -1,8 +1,10 @@
 """exaSPIM pipeline utilites top level namespace definition
 """
 from .imagej_macros import ImagejMacros
-from .imagej_wrapper import main
 
-__all__ = ["ImagejMacros", "main"]
+__all__ = [
+    "ImagejMacros",
+]
+
+__version__ = "0.4.4"
 
-__version__ = "0.2.2"
